This function performs a Monte Carlo sensitivity analysis for causal effects.
causens_monte_carlo(outcome, exposure, confounders, data, ...)The estimated causal effect.
The name of the outcome variable in the data frame.
The name of the exposure variable in the data frame.
The name of the confounders in the data frame.
A data frame containing the exposure, outcome, and confounder variables.
Additional arguments to be passed to the function.