This function provides an estimate of the Average Treatment Effect (ATE) using Bayesian modelling.
causens_sf(
trt_model,
outcome,
data,
bootstrap = FALSE,
B = 1000,
seed = 123,
...
)A point estimate of the corrected ATE.
A model formula specifying the treatment model.
The name of the outcome variable.
A data frame containing the exposure, outcome, and confounder variables.
A logical indicating whether to perform bootstrap estimation of the 95% confidence interval.
If the bootstrap argument is TRUE, the number of bootstrap samples to generate.
An integer to set the random seed for reproducibility.
Additional arguments to be passed to the sensitivity function.