Learn R Programming

causens (version 0.0.3)

summary.causens_sf: Summarize the results of a causal sensitivity analysis via sensitivity function.

Description

Summarize the results of a causal sensitivity analysis via sensitivity function.

Usage

# S3 method for causens_sf
summary(object, ...)

Value

A summary of the results of the causal sensitivity analysis.

Arguments

object

An object of class causens_sf.

...

Additional arguments to be passed to summary.