summary.monte_carlo_causens: Summarize the results of a causal sensitivity analysis via the
Monte Carlo method.
Description
Summarize the results of a causal sensitivity analysis via the
Monte Carlo method.
Usage
# S3 method for monte_carlo_causens
summary(object, ...)
Value
A summary of results from a Monte Carlo causal sensitivity analysis.
Arguments
- object
An object of class causens_monte_carlo.
- ...
Additional arguments to be passed to summary.